@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdfeed.h,v 1.5.2.3 2009/02/05 19:50:55 cvs Exp $
+//      $Id: rdfeed.h,v 1.5.2.5 2009/05/26 18:33:29 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,17 +21,24 @@
 //
 
 #include <qsqldatabase.h>
+#include <qobject.h>
 
 #include <rdsettings.h>
 
 #ifndef RDFEED_H
 #define RDFEED_H
 
-class RDFeed
+#define RDFEED_TOTAL_POST_STEPS 4
+
+class RDFeed : public QObject
 {
+  Q_OBJECT;
  public:
-  RDFeed(const QString &keyname);
-  RDFeed(unsigned id);
+  enum Error {ErrorOk=0,ErrorNoFile=1,ErrorCannotOpenFile=2,
+	      ErrorUnsupportedType=3,ErrorUploadFailed=4,ErrorGeneral=5};
+  enum MediaLinkMode {LinkNone=0,LinkDirect=1,LinkCounted=2};
+  RDFeed(const QString &keyname,QObject *parent=0,const char *name=0);
+  RDFeed(unsigned id,QObject *parent=0,const char *name=0);
   QString keyName() const;
   unsigned id() const;
   bool exists() const;
@@ -95,8 +102,24 @@ class RDFeed
   void setNormalizeLevel(int lvl) const;
   QString redirectPath() const;
   void setRedirectPath(const QString &str);
+  RDFeed::MediaLinkMode mediaLinkMode() const;
+  void setMediaLinkMode(RDFeed::MediaLinkMode mode) const;
+  QString audioUrl(RDFeed::MediaLinkMode mode,unsigned cast_id);
+  unsigned postCut(const QString &cutname,Error *err);
+  unsigned postFile(const QString &srcfile,Error *err);
+  int totalPostSteps() const;
+  static QString errorString(RDFeed::Error err);
+
+ signals:
+  void postProgressChanged(int step);
 
  private:
+  QString GetImportCommand(const QString &srcfile,QString *destfile,
+			   Error *err) const;
+  QString GetExportCommand(const QString &srcfile,QString *destfile,
+			   Error *err) const;
+  unsigned CreateCast(QString *filename,int bytes,int msecs) const;
+  QString GetTempFilename() const;
   void SetRow(const QString &param,int value) const;
   void SetRow(const QString &param,const QString &value) const;
   QString feed_keyname;
