@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.h,v 1.82.2.1 2008-11-07 12:58:17 fredg Exp $
+//      $Id: log_play.h,v 1.82.2.6 2009/03/26 20:27:57 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,8 @@
 #ifndef LOG_PLAY_H
 #define LOG_PLAY_H
 
+#include <vector>
+
 #include <qobject.h>
 #include <qsignalmapper.h>
 #include <qtimer.h>
@@ -37,6 +39,9 @@
 #include <rdcae.h>
 #include <rdevent_player.h>
 #include <rdlog.h>
+#include <rdsimpleplayer.h>
+
+#include <rlmhost.h>
 
 //
 // Widget Settings
@@ -57,9 +62,9 @@ class LogPlay : public QObject,public RDLogEvent
 {
  Q_OBJECT
  public:
- LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname="",
-	 QObject *parent=0,const char *name=0);
-  ~LogPlay();
+  LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
+	  std::vector<RLMHost *> *rlm_hosts,
+	  QObject *parent=0,const char *name=0);
   QString serviceName() const;
   void setServiceName(const QString &svcname);
   QString defaultServiceName() const;
@@ -72,6 +77,11 @@ class LogPlay : public QObject,public RDLogEvent
   void setChannels(int cards[2],int ports[2],
 		   const QString start_rml[2],const QString stop_rml[2]);
   void setSegueLength(int len);
+  void setNowCart(unsigned cartnum);
+  void setNextCart(unsigned cartnum);
+  void auditionHead(int line);
+  void auditionTail(int line);
+  void auditionStop();
   bool play(int line,RDLogLine::StartSource src,
 	    int mport=-1,bool skip_meta=false);
   bool stop(bool all=true,int port=0,int fade=0);
@@ -103,7 +113,7 @@ class LogPlay : public QObject,public RDLogEvent
   RDLogLine::Status status(int line);
   QTime startTime(int line);
   QTime nextStop() const;
-  bool running();
+  bool running(bool include_paused=true);
   void resync();
 
  private slots:
@@ -121,6 +131,8 @@ class LogPlay : public QObject,public RDLogEvent
   void macroStoppedData();
   void timescalingSupportedData(int card,bool state);
   void rescanEventsData();
+  void auditionStartedData();
+  void auditionStoppedData();
 
  signals:
   void renamed();
@@ -129,6 +141,9 @@ class LogPlay : public QObject,public RDLogEvent
   void inserted(int line);
   void removed(int line,int num,bool moving);
   void modified(int line);
+  void auditionHeadPlayed(int line);
+  void auditionTailPlayed(int line);
+  void auditionStopped(int line);
   void played(int line);
   void paused(int line);
   void stopped(int line);
@@ -137,7 +152,7 @@ class LogPlay : public QObject,public RDLogEvent
   void nextEventChanged(int line);
   void activeEventChanged(int line,RDLogLine::TransType trans);
   void nextStopChanged(QTime time);
-  void postPointChanged(QTime point,QTime actual,int offset);
+  void postPointChanged(QTime point,int offset,bool offset_valid,bool running);
   void runStatusChanged(bool running);
   void refreshabilityChanged(bool state);
   void refreshStatusChanged(bool active);
@@ -156,7 +171,7 @@ class LogPlay : public QObject,public RDLogEvent
   QTime GetNextStop(int line);
   void UpdatePostPoint();
   void UpdatePostPoint(int line);
-  int NextPostPoint(int line,QTime *start,int *offset);
+//  int NextPostPoint(int line,QTime *start,int *offset);
   void AdvanceActiveEvent();
   void SetTransTimer(QTime current_time=QTime(),bool stop=true);
   QString GetPortName(int card,int port);
@@ -167,8 +182,6 @@ class LogPlay : public QObject,public RDLogEvent
   bool GetNextPlayable(int *line,bool skip_meta,bool forced_start=false);
   void LogPlayEvent(RDLogLine *logline);
   void RefreshEvents(int line,int line_quan,bool force_update=false);
-  void SendNowNext();
-  void ResolveNowNext(QString *str,RDLogLine **loglines);
   void Playing(int id);
   void Paused(int id);
   void Stopping(int id);
@@ -177,6 +190,7 @@ class LogPlay : public QObject,public RDLogEvent
   void ClearChannel(int deckid);
   RDLogLine::TransType GetTransType(const QString &logname,int line);
   bool ClearBlock(int start_line);
+  void SendNowNext();
   RDCae *play_cae;
   RDAirPlayConf::OpMode play_op_mode;
   int play_slot_id[LOGPLAY_MAX_PLAYS];
@@ -189,7 +203,6 @@ class LogPlay : public QObject,public RDLogEvent
   QTime play_next_stop;
   bool play_running;
   QTime play_post_time;
-  QTime play_start_time;
   int play_post_offset;
   int play_active_line;
   RDLogLine::TransType play_active_trans;
@@ -213,7 +226,6 @@ class LogPlay : public QObject,public RDLogEvent
   QHostAddress play_nownext_address;
   Q_UINT16 play_nownext_port;
   QString play_nownext_rml;
-  RDLogLine *play_prev_logline[2];
   bool play_timescaling_supported[RD_MAX_CARDS];
   QString play_svc_name;
   QString play_defaultsvc_name;
@@ -226,6 +238,15 @@ class LogPlay : public QObject,public RDLogEvent
   bool play_onair_flag;
   int play_duck_volume_port1;
   int play_duck_volume_port2;
+  std::vector<RLMHost *> *play_rlm_hosts;
+  unsigned play_now_cartnum;
+  unsigned play_next_cartnum;
+  unsigned play_prevnow_cartnum;
+  unsigned play_prevnext_cartnum;
+  RDSimplePlayer *play_audition_player;
+  int play_audition_line;
+  bool play_audition_head_played;
+  int play_audition_preroll;
 };
 
 
