@@ -37,10 +37,6 @@
         <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Audition</source>
         <translation type="unfinished"></translation>
@@ -82,11 +78,15 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Overlap</source>
+        <source>Start Transition Type:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No Fade When Segueing At End</source>
+        <source>No Fade at Segue Out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -140,10 +140,6 @@
         <source>Select</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Play</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Pause</source>
         <translation type="unfinished"></translation>
@@ -252,7 +248,33 @@ Log</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>OVERLAP</source>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Next Stop:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log End:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Selected:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audition
+Head</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audition
+Tail</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -353,10 +375,6 @@ Log</source>
         <source>[traffic import]</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>OVRLAP</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MainWidget</name>
