@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: audio_cart.cpp,v 1.46 2007/09/14 14:06:55 fredg Exp $
+//      $Id: audio_cart.cpp,v 1.50 2007/12/29 21:05:36 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,10 +33,10 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 #include <qapplication.h>
 
 #include <rdcddbrecord.h>
+#include <rddb.h>
 #include <rdwavedata.h>
 #include <rd.h>
 #include <rdconf.h>
@@ -196,14 +196,31 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   record_cut_button->setGeometry(550,0,80,50);
   record_cut_button->setPixmap(*pix);
   connect(record_cut_button,SIGNAL(clicked()),this,SLOT(recordCutData()));
+  
+  //
+  // Send to (external) Editor Button (ex: Audacity)
+  //
+  QPushButton *ext_editor_cut_button=
+    new QPushButton(this,"ext_editor_cut_button");
+  ext_editor_cut_button->setGeometry(550,60,80,50);
+  ext_editor_cut_button->setFont(button_font);
+  ext_editor_cut_button->setText(tr("Edit\nAudio"));
+  connect(ext_editor_cut_button,SIGNAL(clicked()),
+	  this,SLOT(extEditorCutData()));
+  int yoffset=60;
+  if((!rdlibrary_conf->enableEditor())||
+     rdstation_conf->editorPath().isEmpty()) {
+    ext_editor_cut_button->hide();
+    yoffset=0;
+  }
 
   //
   // Edit Cut Button
   //
   QPushButton *edit_cut_button=new QPushButton(this,"edit_cut_button");
-  edit_cut_button->setGeometry(550,60,80,50);
+  edit_cut_button->setGeometry(550,60+yoffset,80,50);
   edit_cut_button->setFont(button_font);
-  edit_cut_button->setText(tr("Edit"));
+  edit_cut_button->setText(tr("Edit\nMarkers"));
   connect(edit_cut_button,SIGNAL(clicked()),this,SLOT(editCutData()));
 
   //
@@ -221,16 +238,16 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   p->end();
   QPushButton *import_cut_button=new QPushButton(this,"import_cut_button");
   import_cut_button->setPixmap(*pix);
-  import_cut_button->setGeometry(550,120,80,50);
+  import_cut_button->setGeometry(550,120+yoffset,80,50);
   connect(import_cut_button,SIGNAL(clicked()),this,SLOT(importCutData()));
 
   //
   // Rip Cut Button
   //
   QPushButton *rip_cut_button=new QPushButton(this,"rip_cut_button");
-  rip_cut_button->setGeometry(550,180,80,50);
+  rip_cut_button->setGeometry(550,180+yoffset,80,50);
   rip_cut_button->setFont(button_font);
-  rip_cut_button->setText(tr("Rip"));
+  rip_cut_button->setText(tr("Rip CD"));
   connect(rip_cut_button,SIGNAL(clicked()),this,SLOT(ripCutData()));
 
   //
@@ -243,12 +260,13 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   }
   rip_cut_button->setEnabled(rdcart_modification_allowed);
   import_cut_button->setEnabled(rdcart_modification_allowed);
+  ext_editor_cut_button->setEnabled(rdcart_modification_allowed);
 }
 
 
 QSize AudioCart::sizeHint() const
 {
-  return QSize(640,240);
+  return QSize(640,290);
 } 
 
 
@@ -303,7 +321,7 @@ void AudioCart::deleteCutData()
   QString sql=QString().sprintf("select CUT_NAME from RECORDINGS where \
                                  CUT_NAME=\"%s\"",
 				(const char *)item->text(11));
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     if(QMessageBox::warning(this,tr("RDCatch Event Exists"),
 			    tr("This cut is used in one or more RDCatch events!\nDo you still want to delete it?"),QMessageBox::Yes,QMessageBox::No)==QMessageBox::No) {
@@ -355,6 +373,24 @@ void AudioCart::copyCutData()
   paste_cut_button->setEnabled(rdcart_modification_allowed);
 }
 
+void AudioCart::extEditorCutData()
+{
+  if(rdcart_cut_list->currentItem()==0) {
+    return;
+  }
+
+  QString cmd=rdstation_conf->editorPath();
+  cmd.replace("%f",RDCut::pathName(rdcart_cut_list->currentItem()->text(11)));
+  // FIXME: other replace commands to match: lib/rdcart_dialog.cpp editorData()
+  //        These substitions should be documented (maybe a text file),
+  //            ex: %f = cart_cut filename
+  //        and possibly also add some tooltips with help advice
+
+  if(fork()==0) {
+    system(cmd+" &");
+    exit(0);
+  }
+}
 
 void AudioCart::pasteCutData()
 {
@@ -564,12 +600,14 @@ void AudioCart::copyProgressData(const QVariant &step)
 
 void AudioCart::RefreshList()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   RDListViewItem *l;
   unsigned total_length=0;
   QDateTime current_datetime=
     QDateTime(QDate::currentDate(),QTime::currentTime());
+  int pass=0;
+  bool err=false;
 
   UpdateCutCount();
   rdcart_cut_list->clear();
@@ -579,18 +617,24 @@ void AudioCart::RefreshList()
                          END_DATETIME,START_DAYPART,END_DAYPART,MON,TUE,WED,\
                          THU,FRI,SAT,SUN from CUTS where CART_NUMBER=%d",
 			rdcart_cart->number());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     l=new RDListViewItem(rdcart_cut_list);
     l->setText(0,q->value(0).toString());
     l->setText(1,q->value(1).toString());
     l->setText(2,RDGetTimeLength(q->value(2).toUInt()));
     if (q->value(0) == 0){// zero weight
-	  l->setBackgroundColor(RD_CART_ERROR_COLOR);
+      l->setBackgroundColor(RD_CART_ERROR_COLOR);
+      if(pass==0) {
+	err=true;
+      }
     } else {
       switch(ValidateCut(q,9,RDCart::NeverValid,current_datetime)) {
       case RDCart::NeverValid:
 	l->setBackgroundColor(RD_CART_ERROR_COLOR);
+	if(pass==0) {
+	  err=true;
+	}
 	break;
 	
       case RDCart::ConditionallyValid:
@@ -601,10 +645,16 @@ void AudioCart::RefreshList()
 	else {
 	  l->setBackgroundColor(RD_CART_CONDITIONAL_COLOR);
 	}
+	if(pass==0) {
+	  err=true;
+	}
 	break;
 	
       case RDCart::EvergreenValid:
 	l->setBackgroundColor(RD_CART_EVERGREEN_COLOR);
+	if(pass==0) {
+	  err=true;
+	}
 	break;
 	
       case RDCart::AlwaysValid:
@@ -645,6 +695,7 @@ void AudioCart::RefreshList()
     }
     l->setText(11,q->value(8).toString());
     total_length+=q->value(2).toUInt();
+    pass++;
   }
   if(q->size()>0) {
     rdcart_average_length=total_length/q->size();
@@ -654,7 +705,7 @@ void AudioCart::RefreshList()
   }
   delete q;
   if(((l=(RDListViewItem *)rdcart_cut_list->firstChild())!=NULL)&&
-    rdcart_select_cut) {
+     ((!err)||rdcart_select_cut)) {
     rdcart_cut_list->setSelected(l,true);
     rdcart_select_cut=false;
   }
@@ -676,7 +727,7 @@ void AudioCart::RefreshLine(RDListViewItem *item)
                          where CART_NUMBER=%d && CUT_NAME=\"%s\"",
 			rdcart_cart->number(),
 			(const char *)cut_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     item->setText(0,q->value(0).toString());
     item->setText(1,q->value(1).toString());
