@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: ripcd.h,v 1.47.2.2 2008-12-08 16:44:21 fredg Exp $
+//      $Id: ripcd.h,v 1.47.2.3 2009/08/07 01:14:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -60,6 +60,7 @@
 #include <btss42.h>
 #include <livewire.h>
 #include <quartz1.h>
+#include <btss44.h>
 
 //
 // Global RIPCD Definitions
@@ -156,14 +157,13 @@ class MainObject : public QObject
   BtSs42 *ripcd_btss42[MAX_MATRICES];
   LiveWire *ripcd_livewire[MAX_MATRICES];
   Quartz1 *ripcd_quartz1[MAX_MATRICES];
+  BtSs44 *ripcd_btss44[MAX_MATRICES];
   bool ripcd_gpi_state[MAX_MATRICES][MAX_GPIO_PINS];
   bool ripcd_gpo_state[MAX_MATRICES][MAX_GPIO_PINS];
   int ripcd_gpi_macro[MAX_MATRICES][MAX_GPIO_PINS][2];
   int ripcd_gpo_macro[MAX_MATRICES][MAX_GPIO_PINS][2];
   bool ripcd_gpi_mask[MAX_MATRICES][MAX_GPIO_PINS];
   bool ripcd_gpo_mask[MAX_MATRICES][MAX_GPIO_PINS];
-//  bool ripcd_gpi_polarity[MAX_MATRICES][MAX_GPIO_PINS];
-//  bool ripcd_gpo_polarity[MAX_MATRICES][MAX_GPIO_PINS];
   int ripcd_gpis[MAX_MATRICES];
   int ripcd_gpos[MAX_MATRICES];
   bool ripcd_tty_inuse[MAX_TTYS];
